@@ -24,7 +24,7 @@
 from __future__ import annotations
 
 import typing
-from sigparse._sigparse import sigparse, Parameter
+from sigparse._sigparse import sigparse, Parameter, Signature
 from sigparse._classparse import classparse, ClassVar
 from sigparse._pep604 import global_PEP604
 from sigparse import utils
@@ -33,6 +33,7 @@ __all__: typing.Sequence[str] = (
     "classparse",
     "sigparse",
     "Parameter",
+    "Signature",
     "ClassVar",
     "global_PEP604",
     "utils",
